from setuptools import setup

setup(name='spdsnd_distributions',
      version='0.1',
      description='Gaussian and Binomial distributions',
      packages=['spdsnd_distributions'],
      zip_safe=False)
